from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Float, Boolean, Int

Anvi_Display_Structure_V0_1_0 = CommandToolBuilder(tool="anvi_display_structure", base_command=["anvi-display-structure"], inputs=[ToolInput(tag="in_profile_db", input_type=String(optional=True), prefix="--profile-db", doc=InputDocumentation(doc="Anvi'o profile database")), ToolInput(tag="in_contigs_db", input_type=String(optional=True), prefix="--contigs-db", doc=InputDocumentation(doc="Anvi'o contigs database generated by 'anvi-gen-\ncontigs'")), ToolInput(tag="in_variability_profile", input_type=String(optional=True), prefix="--variability-profile", doc=InputDocumentation(doc="The output of anvi-gen-variability-profile, or a\ndifferent variant-calling output that has been\nconverted to the anvi'o format.")), ToolInput(tag="in_splits_of_interest", input_type=File(optional=True), prefix="--splits-of-interest", doc=InputDocumentation(doc="A file with split names. There should be only one\ncolumn in the file, and each line should correspond to\na unique split name.")), ToolInput(tag="in_collection_name", input_type=String(optional=True), prefix="--collection-name", doc=InputDocumentation(doc="Collection name.")), ToolInput(tag="in_bin_id", input_type=String(optional=True), prefix="--bin-id", doc=InputDocumentation(doc="If provided, any genes found in both your bin and your\nstructure database will be available for display.")), ToolInput(tag="in_samples_of_interest", input_type=File(optional=True), prefix="--samples-of-interest", doc=InputDocumentation(doc="A file with samples names. There should be only one\ncolumn in the file, and each line should correspond to\na unique sample name (without a column header).")), ToolInput(tag="in_genes_of_interest", input_type=File(optional=True), prefix="--genes-of-interest", doc=InputDocumentation(doc="A file with anvi'o gene caller IDs. There should be\nonly one column in the file, and each line should\ncorrespond to a unique gene caller id (without a\ncolumn header).")), ToolInput(tag="in_gene_caller_ids", input_type=String(optional=True), prefix="--gene-caller-ids", doc=InputDocumentation(doc="Gene caller ids. Multiple of them can be declared\nseparated by a delimiter (the default is a comma). In\nanvi-gen-variability-profile, if you declare nothing\nyou will get all genes matching your other filtering\ncriteria. In other programs, you may get everything,\nnothing, or an error. It really depends on the\nsituation. Fortunately, mistakes are cheap, so it's\nworth a try.")), ToolInput(tag="in_min_departure_from_consensus", input_type=Float(optional=True), prefix="--min-departure-from-consensus", doc=InputDocumentation(doc="Takes a value between 0 and 1, where 1 is maximum\ndivergence from the consensus. it can be an expensive\noperation to display every variable position, and so\nthe default is 0.05. To display every variable\nposition, set this parameter to 0")), ToolInput(tag="in_sa_avs_only", input_type=Boolean(optional=True), prefix="--SAAVs-only", doc=InputDocumentation(doc="If provided, variability will be generated for single\namino acid variants (SAAVs) and not for single codon\nvariants (SCVs). This could save you some time if\nyou're only interested in SAAVs.")), ToolInput(tag="in_s_cvs_only", input_type=Boolean(optional=True), prefix="--SCVs-only", doc=InputDocumentation(doc="If provided, variability will be generated for single\ncodon variants (SCVs) and not for single amino acid\nvariants (SAAVs). This could save you some time if\nyou're only interested in SCVs.")), ToolInput(tag="in_ip_address", input_type=Float(optional=True), prefix="--ip-address", doc=InputDocumentation(doc="IP address for the HTTP server. The default ip address\n(0.0.0.0) should work just fine for most.")), ToolInput(tag="in_port_number", input_type=Int(optional=True), prefix="--port-number", doc=InputDocumentation(doc="Port number to use for anvi'o services. If nothing is\ndeclared, anvi'o will try to find a suitable port\nnumber, starting from the default port number, 8080.")), ToolInput(tag="in_browser_path", input_type=File(optional=True), prefix="--browser-path", doc=InputDocumentation(doc="By default, anvi'o will use your default browser to\nlaunch the interactive interface. If you would like to\nuse something else than your system default, you can\nprovide a full path for an alternative browser using\nthis parameter, and hope for the best. For instance we\nare using this parameter to call Google's experimental\nbrowser, Canary, which performs better with demanding\nvisualizations.")), ToolInput(tag="in_server_only", input_type=Boolean(optional=True), prefix="--server-only", doc=InputDocumentation(doc="The default behavior is to start the local server, and\nfire up a browser that connects to the server. If you\nhave other plans, and want to start the server without\ncalling the browser, this is the flag you need.")), ToolInput(tag="in_password_protected", input_type=Boolean(optional=True), prefix="--password-protected", doc=InputDocumentation(doc="If this flag is set, command line tool will ask you to\nenter a password and interactive interface will be\nonly accessible after entering same password. This\noption is recommended for shared machines like\nclusters or shared networks where computers are not\nisolated.\n")), ToolInput(tag="in_s", input_type=String(optional=True), prefix="-s", doc=InputDocumentation(doc="")), ToolInput(tag="in_an_vi_gen_structure_database_dot", input_type=String(), position=0, doc=InputDocumentation(doc="-s STRUCTURE_DB, --structure-db STRUCTURE_DB\nAnvi'o structure database."))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Anvi_Display_Structure_V0_1_0().translate("wdl", allow_empty_container=True)

